@@ -9,8 +9,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.ConnectWisdomService 1.21.45\nVersion:         1.21.45\nBuilder"
-        " version: 7.5.9\nDocs:           "
+        "Type annotations for boto3.ConnectWisdomService 1.22.0\nVersion:        "
+        " 1.22.0.post1\nBuilder version: 7.5.9\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_wisdom//\nBoto3 docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/wisdom.html#ConnectWisdomService\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.21.45")
+    print("1.22.0.post1")
 
 
 def main() -> None:
