@@ -1,7 +1,7 @@
 """
 Type annotations for wisdom service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_wisdom/literals/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_wisdom/literals/)
 
 Usage::
 
@@ -33,6 +33,9 @@ __all__ = (
     "ListContentsPaginatorName",
     "ListKnowledgeBasesPaginatorName",
     "QueryAssistantPaginatorName",
+    "RecommendationSourceTypeType",
+    "RecommendationTriggerTypeType",
+    "RecommendationTypeType",
     "RelevanceLevelType",
     "SearchContentPaginatorName",
     "SearchSessionsPaginatorName",
@@ -79,6 +82,9 @@ ListAssistantsPaginatorName = Literal["list_assistants"]
 ListContentsPaginatorName = Literal["list_contents"]
 ListKnowledgeBasesPaginatorName = Literal["list_knowledge_bases"]
 QueryAssistantPaginatorName = Literal["query_assistant"]
+RecommendationSourceTypeType = Literal["ISSUE_DETECTION", "OTHER", "RULE_EVALUATION"]
+RecommendationTriggerTypeType = Literal["QUERY"]
+RecommendationTypeType = Literal["KNOWLEDGE_CONTENT"]
 RelevanceLevelType = Literal["HIGH", "LOW", "MEDIUM"]
 SearchContentPaginatorName = Literal["search_content"]
 SearchSessionsPaginatorName = Literal["search_sessions"]
@@ -303,6 +309,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
